@@ -23,10 +23,11 @@
 #include <float.h>
 #include <gdk/gdk.h>
 
-#import "GdkMacosCairoView.h"
+#import "GdkMacosView.h"
 
 #include "gdkmacossurface-private.h"
 
+#include "gdkdebug.h"
 #include "gdkdeviceprivate.h"
 #include "gdkdisplay.h"
 #include "gdkeventsprivate.h"
@@ -64,14 +65,86 @@ window_is_fullscreen (GdkMacosSurface *self)
 }
 
 void
-_gdk_macos_surface_reposition_children (GdkMacosSurface *self)
+_gdk_macos_surface_request_frame (GdkMacosSurface *self)
 {
   g_assert (GDK_IS_MACOS_SURFACE (self));
 
+  if (self->awaiting_frame)
+    return;
+
+  if (self->best_monitor != NULL)
+    {
+      self->awaiting_frame = TRUE;
+      _gdk_macos_monitor_add_frame_callback (GDK_MACOS_MONITOR (self->best_monitor), self);
+      gdk_surface_freeze_updates (GDK_SURFACE (self));
+    }
+}
+
+static void
+_gdk_macos_surface_cancel_frame (GdkMacosSurface *self)
+{
+  g_assert (GDK_IS_MACOS_SURFACE (self));
+
+  if (!self->awaiting_frame)
+    return;
+
+  if (self->best_monitor != NULL)
+    {
+      self->awaiting_frame = FALSE;
+      _gdk_macos_monitor_remove_frame_callback (GDK_MACOS_MONITOR (self->best_monitor), self);
+      gdk_surface_thaw_updates (GDK_SURFACE (self));
+    }
+}
+
+void
+_gdk_macos_surface_frame_presented (GdkMacosSurface *self,
+                                    gint64           presentation_time,
+                                    gint64           refresh_interval)
+{
+  GdkFrameTimings *timings;
+  GdkFrameClock *frame_clock;
+
+  g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
+
+  self->awaiting_frame = FALSE;
+
   if (GDK_SURFACE_DESTROYED (self))
     return;
 
-  if (!gdk_surface_get_mapped (GDK_SURFACE (self)))
+  frame_clock = gdk_surface_get_frame_clock (GDK_SURFACE (self));
+
+  if (self->pending_frame_counter)
+    {
+      timings = gdk_frame_clock_get_timings (frame_clock, self->pending_frame_counter);
+
+      if (timings != NULL)
+        {
+          timings->presentation_time = presentation_time - refresh_interval;
+          timings->complete = TRUE;
+        }
+
+      self->pending_frame_counter = 0;
+    }
+
+  timings = gdk_frame_clock_get_current_timings (frame_clock);
+
+  if (timings != NULL)
+    {
+      timings->refresh_interval = refresh_interval;
+      timings->predicted_presentation_time = presentation_time;
+    }
+
+  if (GDK_SURFACE_IS_MAPPED (GDK_SURFACE (self)))
+    gdk_surface_thaw_updates (GDK_SURFACE (self));
+}
+
+void
+_gdk_macos_surface_reposition_children (GdkMacosSurface *self)
+{
+  g_assert (GDK_IS_MACOS_SURFACE (self));
+
+
+  if (GDK_SURFACE_DESTROYED (self))
     return;
 
   for (const GList *iter = GDK_SURFACE (self)->children;
@@ -85,15 +158,23 @@ _gdk_macos_surface_reposition_children (GdkMacosSurface *self)
       if (GDK_IS_MACOS_POPUP_SURFACE (child))
         _gdk_macos_popup_surface_reposition (GDK_MACOS_POPUP_SURFACE (child));
     }
-
-  if (GDK_IS_POPUP (self) && self->did_initial_present)
-    gdk_surface_request_layout (GDK_SURFACE (self));
 }
 
 static void
 gdk_macos_surface_set_input_region (GdkSurface     *surface,
                                     cairo_region_t *region)
 {
+  GdkMacosSurface *self = (GdkMacosSurface *)surface;
+  cairo_rectangle_int_t rect;
+
+  g_assert (GDK_IS_MACOS_SURFACE (self));
+
+  if (self->window == NULL)
+    return;
+
+  cairo_region_get_extents (region, &rect);
+
+  [(GdkMacosBaseView *)[self->window contentView] setInputArea:&rect];
 }
 
 static void
@@ -105,15 +186,8 @@ gdk_macos_surface_set_opaque_region (GdkSurface     *surface,
 
   g_assert (GDK_IS_MACOS_SURFACE (self));
 
-  if (region != self->opaque_region)
-    {
-      g_clear_pointer (&self->opaque_region, cairo_region_destroy);
-      self->opaque_region = cairo_region_copy (region);
-    }
-
-  if ((nsview = _gdk_macos_surface_get_view (GDK_MACOS_SURFACE (surface))) &&
-      GDK_IS_MACOS_CAIRO_VIEW (nsview))
-    [(GdkMacosCairoView *)nsview setOpaqueRegion:region];
+  if ((nsview = _gdk_macos_surface_get_view (GDK_MACOS_SURFACE (surface))))
+    [(GdkMacosView *)nsview setOpaqueRegion:region];
 }
 
 static void
@@ -122,12 +196,16 @@ gdk_macos_surface_hide (GdkSurface *surface)
   GdkMacosSurface *self = (GdkMacosSurface *)surface;
   GdkSeat *seat;
   gboolean was_mapped;
+  gboolean was_key;
 
   g_assert (GDK_IS_MACOS_SURFACE (self));
 
-  _gdk_macos_display_remove_frame_callback (GDK_MACOS_DISPLAY (surface->display), self);
+  self->show_on_next_swap = FALSE;
 
-  was_mapped = GDK_SURFACE_IS_MAPPED (GDK_SURFACE (self));
+  _gdk_macos_surface_cancel_frame (self);
+
+  was_mapped = GDK_SURFACE_IS_MAPPED (surface);
+  was_key = [self->window isKeyWindow];
 
   seat = gdk_display_get_default_seat (surface->display);
   gdk_seat_ungrab (seat);
@@ -136,8 +214,26 @@ gdk_macos_surface_hide (GdkSurface *surface)
 
   _gdk_surface_clear_update_area (surface);
 
-  if (was_mapped)
-    gdk_surface_freeze_updates (GDK_SURFACE (self));
+  g_clear_object (&self->buffer);
+  g_clear_object (&self->front);
+
+  if (was_key)
+    {
+      GdkSurface *parent;
+
+      if (GDK_IS_TOPLEVEL (surface))
+        parent = surface->transient_for;
+      else
+        parent = surface->parent;
+
+      /* Return key input to the parent window if necessary */
+      if (parent != NULL && GDK_SURFACE_IS_MAPPED (parent))
+        {
+          GdkMacosWindow *parentWindow = GDK_MACOS_SURFACE (parent)->window;
+
+          [parentWindow showAndMakeKey:YES];
+        }
+    }
 }
 
 static int
@@ -181,6 +277,7 @@ gdk_macos_surface_begin_frame (GdkMacosSurface *self)
 {
   g_assert (GDK_IS_MACOS_SURFACE (self));
 
+  self->in_frame = TRUE;
 }
 
 static void
@@ -201,11 +298,9 @@ gdk_macos_surface_end_frame (GdkMacosSurface *self)
   if ((timings = gdk_frame_clock_get_current_timings (frame_clock)))
     self->pending_frame_counter = timings->frame_counter;
 
-  if (GDK_SURFACE_IS_MAPPED (GDK_SURFACE (self)))
-    {
-      _gdk_macos_display_add_frame_callback (GDK_MACOS_DISPLAY (display), self);
-      gdk_surface_freeze_updates (GDK_SURFACE (self));
-    }
+  self->in_frame = FALSE;
+
+  _gdk_macos_surface_request_frame (self);
 }
 
 static void
@@ -379,18 +474,20 @@ gdk_macos_surface_destroy (GdkSurface *surface,
   GdkMacosWindow *window = g_steal_pointer (&self->window);
   GdkFrameClock *frame_clock;
 
+  _gdk_macos_surface_cancel_frame (self);
+  g_clear_object (&self->best_monitor);
+
   if ((frame_clock = gdk_surface_get_frame_clock (GDK_SURFACE (self))))
     {
       g_signal_handlers_disconnect_by_func (frame_clock,
                                             G_CALLBACK (gdk_macos_surface_before_paint),
                                             self);
       g_signal_handlers_disconnect_by_func (frame_clock,
-                                            G_CALLBACK (gdk_macos_surface_before_paint),
+                                            G_CALLBACK (gdk_macos_surface_after_paint),
                                             self);
     }
 
   g_clear_pointer (&self->title, g_free);
-  g_clear_pointer (&self->opaque_region, cairo_region_destroy);
 
   if (window != NULL)
     [window close];
@@ -399,6 +496,9 @@ gdk_macos_surface_destroy (GdkSurface *surface,
 
   g_clear_pointer (&self->monitors, g_ptr_array_unref);
 
+  g_clear_object (&self->buffer);
+  g_clear_object (&self->front);
+
   g_assert (self->sorted.prev == NULL);
   g_assert (self->sorted.next == NULL);
   g_assert (self->frame.prev == NULL);
@@ -419,15 +519,6 @@ gdk_macos_surface_constructed (GObject *object)
 
   G_OBJECT_CLASS (gdk_macos_surface_parent_class)->constructed (object);
 
-  if (self->window != NULL)
-    {
-      NSRect bounds = [[self->window contentView] bounds];
-
-      GDK_SURFACE (self)->width = bounds.size.width;
-      GDK_SURFACE (self)->height = bounds.size.height;
-      _gdk_macos_surface_update_position (self);
-    }
-
   if ((frame_clock = gdk_surface_get_frame_clock (GDK_SURFACE (self))))
     {
       g_signal_connect_object (frame_clock,
@@ -441,6 +532,9 @@ gdk_macos_surface_constructed (GObject *object)
                                self,
                                G_CONNECT_SWAPPED);
     }
+
+  if (self->window != NULL)
+    _gdk_macos_surface_configure (self);
 }
 
 static void
@@ -535,7 +629,7 @@ _gdk_macos_surface_new (GdkMacosDisplay   *display,
   g_return_val_if_fail (GDK_IS_MACOS_DISPLAY (display), NULL);
 
   if (parent != NULL)
-    frame_clock = g_object_ref (gdk_surface_get_frame_clock (parent));
+    frame_clock = g_object_ref (parent->frame_clock);
   else
     frame_clock = _gdk_frame_clock_idle_new ();
 
@@ -592,6 +686,29 @@ _gdk_macos_surface_get_shadow (GdkMacosSurface *self,
     *right = self->shadow_right;
 }
 
+gboolean
+_gdk_macos_surface_is_opaque (GdkMacosSurface *self)
+{
+  GdkSurface *surface = (GdkSurface *)self;
+
+  g_return_val_if_fail (GDK_IS_MACOS_SURFACE (self), FALSE);
+
+  if (surface->opaque_region != NULL &&
+      cairo_region_num_rectangles (surface->opaque_region) == 1)
+    {
+      cairo_rectangle_int_t extents;
+
+      cairo_region_get_extents (surface->opaque_region, &extents);
+
+      return (extents.x == 0 &&
+              extents.y == 0 &&
+              extents.width == GDK_SURFACE (self)->width &&
+              extents.height == GDK_SURFACE (self)->height);
+    }
+
+  return FALSE;
+}
+
 const char *
 _gdk_macos_surface_get_title (GdkMacosSurface *self)
 {
@@ -699,63 +816,60 @@ _gdk_macos_surface_update_fullscreen_state (GdkMacosSurface *self)
 }
 
 void
-_gdk_macos_surface_update_position (GdkMacosSurface *self)
+_gdk_macos_surface_configure (GdkMacosSurface *self)
 {
-  GdkSurface *surface = GDK_SURFACE (self);
-  GdkDisplay *display = gdk_surface_get_display (surface);
-  NSRect frame_rect = [self->window frame];
-  NSRect content_rect = [self->window contentRectForFrameRect:frame_rect];
+  GdkSurface *surface = (GdkSurface *)self;
+  GdkMacosDisplay *display;
+  GdkMacosSurface *parent;
+  NSRect frame_rect;
+  NSRect content_rect;
+
+  g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
+
+  if (GDK_SURFACE_DESTROYED (self))
+    return;
+
+  if (surface->parent != NULL)
+    parent = GDK_MACOS_SURFACE (surface->parent);
+  else if (surface->transient_for != NULL)
+    parent = GDK_MACOS_SURFACE (surface->transient_for);
+  else
+    parent = NULL;
+
+  display = GDK_MACOS_DISPLAY (GDK_SURFACE (self)->display);
+  frame_rect = [self->window frame];
+  content_rect = [self->window contentRectForFrameRect:frame_rect];
 
   _gdk_macos_display_from_display_coords (GDK_MACOS_DISPLAY (display),
                                           content_rect.origin.x,
                                           content_rect.origin.y + content_rect.size.height,
                                           &self->root_x, &self->root_y);
 
-  if (surface->parent != NULL)
+  if (parent != NULL)
     {
-      surface->x = self->root_x - GDK_MACOS_SURFACE (surface->parent)->root_x;
-      surface->y = self->root_y - GDK_MACOS_SURFACE (surface->parent)->root_y;
+      surface->x = self->root_x - parent->root_x;
+      surface->y = self->root_y - parent->root_y;
     }
   else
     {
       surface->x = self->root_x;
       surface->y = self->root_y;
     }
-}
 
-void
-_gdk_macos_surface_publish_timings (GdkMacosSurface *self,
-                                    gint64           presentation_time,
-                                    gint64           refresh_interval)
-{
-  GdkFrameTimings *timings;
-  GdkFrameClock *frame_clock;
-
-  g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
-
-  if (!(frame_clock = gdk_surface_get_frame_clock (GDK_SURFACE (self))))
-    return;
-
-  if (self->pending_frame_counter)
+  if (surface->width != content_rect.size.width ||
+      surface->height != content_rect.size.height)
     {
-      timings = gdk_frame_clock_get_timings (frame_clock, self->pending_frame_counter);
+      surface->width = content_rect.size.width;
+      surface->height = content_rect.size.height;
 
-      if (timings != NULL)
-        {
-          timings->presentation_time = presentation_time - refresh_interval;
-          timings->complete = TRUE;
-        }
+      g_clear_object (&self->buffer);
+      g_clear_object (&self->front);
 
-      self->pending_frame_counter = 0;
+      _gdk_surface_update_size (surface);
+      gdk_surface_invalidate_rect (surface, NULL);
     }
 
-  timings = gdk_frame_clock_get_current_timings (frame_clock);
-
-  if (timings != NULL)
-    {
-      timings->refresh_interval = refresh_interval;
-      timings->predicted_presentation_time = presentation_time;
-    }
+  _gdk_macos_surface_reposition_children (self);
 }
 
 void
@@ -768,69 +882,18 @@ _gdk_macos_surface_show (GdkMacosSurface *self)
   if (GDK_SURFACE_DESTROYED (self))
     return;
 
+  _gdk_macos_display_clear_sorting (GDK_MACOS_DISPLAY (GDK_SURFACE (self)->display));
+  self->show_on_next_swap = TRUE;
+
   was_mapped = GDK_SURFACE_IS_MAPPED (GDK_SURFACE (self));
 
-  if (!was_mapped)
-    gdk_surface_set_is_mapped (GDK_SURFACE (self), TRUE);
-
-  _gdk_macos_display_clear_sorting (GDK_MACOS_DISPLAY (GDK_SURFACE (self)->display));
-
-  [self->window showAndMakeKey:YES];
-
   if (!was_mapped)
     {
-      if (gdk_surface_get_mapped (GDK_SURFACE (self)))
-        {
-          _gdk_macos_surface_update_position (self);
-          gdk_surface_invalidate_rect (GDK_SURFACE (self), NULL);
-          gdk_surface_thaw_updates (GDK_SURFACE (self));
-        }
+      gdk_surface_set_is_mapped (GDK_SURFACE (self), TRUE);
+      gdk_surface_request_layout (GDK_SURFACE (self));
+      gdk_surface_invalidate_rect (GDK_SURFACE (self), NULL);
+      gdk_surface_thaw_updates (GDK_SURFACE (self));
     }
-
-  [[self->window contentView] setNeedsDisplay:YES];
-}
-
-CGContextRef
-_gdk_macos_surface_acquire_context (GdkMacosSurface *self,
-                                    gboolean         clear_scale,
-                                    gboolean         antialias)
-{
-  CGContextRef cg_context;
-
-  g_return_val_if_fail (GDK_IS_MACOS_SURFACE (self), NULL);
-
-  if (GDK_SURFACE_DESTROYED (self))
-    return NULL;
-
-  if (!(cg_context = [[NSGraphicsContext currentContext] CGContext]))
-    return NULL;
-
-  CGContextSaveGState (cg_context);
-
-  if (!antialias)
-    CGContextSetAllowsAntialiasing (cg_context, antialias);
-
-  if (clear_scale)
-    {
-      CGSize scale;
-
-      scale = CGSizeMake (1.0, 1.0);
-      scale = CGContextConvertSizeToDeviceSpace (cg_context, scale);
-
-      CGContextScaleCTM (cg_context, 1.0 / fabs (scale.width), 1.0 / fabs (scale.height));
-    }
-
-  return cg_context;
-}
-
-void
-_gdk_macos_surface_release_context (GdkMacosSurface *self,
-                                    CGContextRef     cg_context)
-{
-  g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
-
-  CGContextRestoreGState (cg_context);
-  CGContextSetAllowsAntialiasing (cg_context, TRUE);
 }
 
 void
@@ -882,52 +945,89 @@ _gdk_macos_surface_move_resize (GdkMacosSurface *self,
   GdkDisplay *display;
   NSRect content_rect;
   NSRect frame_rect;
-  gboolean size_changed;
+  gboolean ignore_move;
+  gboolean ignore_size;
+  GdkRectangle current;
 
   g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
 
-  if ((x == -1 || (x == self->root_x)) &&
-      (y == -1 || (y == self->root_y)) &&
-      (width == -1 || (width == surface->width)) &&
-      (height == -1 || (height == surface->height)))
+  /* Query for up-to-date values in case we're racing against
+   * an incoming frame notify which could be queued behind whatever
+   * we're processing right now.
+   */
+  frame_rect = [self->window frame];
+  content_rect = [self->window contentRectForFrameRect:frame_rect];
+  _gdk_macos_display_from_display_coords (GDK_MACOS_DISPLAY (GDK_SURFACE (self)->display),
+                                          content_rect.origin.x, content_rect.origin.y,
+                                          &current.x, &current.y);
+  current.width = content_rect.size.width;
+  current.height = content_rect.size.height;
+
+  /* Check if we can ignore the operation all together */
+  ignore_move = (x == -1 || (x == current.x)) &&
+                (y == -1 || (y == current.y));
+  ignore_size = (width == -1 || (width == current.width)) &&
+                (height == -1 || (height == current.height));
+
+  if (ignore_move && ignore_size)
     return;
 
   display = gdk_surface_get_display (surface);
 
   if (width == -1)
-    width = surface->width;
+    width = current.width;
 
   if (height == -1)
-    height = surface->height;
+    height = current.height;
 
   if (x == -1)
-    x = self->root_x;
+    x = current.x;
 
   if (y == -1)
-    y = self->root_y;
-
-  size_changed = height != surface->height || width != surface->width;
-
-  if (GDK_IS_MACOS_SURFACE (surface->parent))
-    {
-      surface->x = x - GDK_MACOS_SURFACE (surface->parent)->root_x;
-      surface->y = y - GDK_MACOS_SURFACE (surface->parent)->root_y;
-    }
-  else
-    {
-      surface->x = x;
-      surface->y = y;
-    }
+    y = current.y;
 
   _gdk_macos_display_to_display_coords (GDK_MACOS_DISPLAY (display),
-                                        x, y + height, &x, &y);
+                                        x, y + height,
+                                        &x, &y);
+
+  if (!ignore_move)
+    content_rect.origin = NSMakePoint (x, y);
+
+  if (!ignore_size)
+    content_rect.size = NSMakeSize (width, height);
 
-  content_rect = NSMakeRect (x, y, width, height);
   frame_rect = [self->window frameRectForContentRect:content_rect];
-  [self->window setFrame:frame_rect display:YES];
+  [self->window setFrame:frame_rect display:NO];
+}
 
-  if (size_changed)
-    gdk_surface_invalidate_rect (surface, NULL);
+void
+_gdk_macos_surface_user_resize (GdkMacosSurface *self,
+                                CGRect           new_frame)
+{
+  GdkMacosDisplay *display;
+  CGRect content_rect;
+  int root_x, root_y;
+
+  g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
+  g_return_if_fail (GDK_IS_TOPLEVEL (self));
+
+  if (GDK_SURFACE_DESTROYED (self))
+    return;
+
+  display = GDK_MACOS_DISPLAY (GDK_SURFACE (self)->display);
+  content_rect = [self->window contentRectForFrameRect:new_frame];
+
+  _gdk_macos_display_from_display_coords (display,
+                                          new_frame.origin.x,
+                                          new_frame.origin.y + new_frame.size.height,
+                                          &root_x, &root_y);
+
+  self->next_layout.root_x = root_x;
+  self->next_layout.root_y = root_y;
+  self->next_layout.width = content_rect.size.width;
+  self->next_layout.height = content_rect.size.height;
+
+  gdk_surface_request_layout (GDK_SURFACE (self));
 }
 
 gboolean
@@ -952,14 +1052,24 @@ void
 _gdk_macos_surface_monitor_changed (GdkMacosSurface *self)
 {
   GListModel *monitors;
+  GdkMonitor *best = NULL;
   GdkRectangle rect;
   GdkRectangle intersect;
   GdkDisplay *display;
   GdkMonitor *monitor;
   guint n_monitors;
+  int best_area = 0;
 
   g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
 
+  if (self->in_change_monitor)
+    return;
+
+  self->in_change_monitor = TRUE;
+
+  _gdk_macos_surface_cancel_frame (self);
+  _gdk_macos_surface_configure (self);
+
   rect.x = self->root_x;
   rect.y = self->root_y;
   rect.width = GDK_SURFACE (self)->width;
@@ -995,28 +1105,14 @@ _gdk_macos_surface_monitor_changed (GdkMacosSurface *self)
       g_object_unref (monitor);
     }
 
-  _gdk_surface_update_size (GDK_SURFACE (self));
-  gdk_surface_invalidate_rect (GDK_SURFACE (self), NULL);
-}
-
-GdkMonitor *
-_gdk_macos_surface_get_best_monitor (GdkMacosSurface *self)
-{
-  GdkMonitor *best = NULL;
-  GdkRectangle rect;
-  int best_area = 0;
-
-  g_return_val_if_fail (GDK_IS_MACOS_SURFACE (self), NULL);
-
-  rect.x = self->root_x;
-  rect.y = self->root_y;
-  rect.width = GDK_SURFACE (self)->width;
-  rect.height = GDK_SURFACE (self)->height;
+  /* We need to create a new IOSurface for this monitor */
+  g_clear_object (&self->buffer);
+  g_clear_object (&self->front);
 
+  /* Determine the best-fit monitor */
   for (guint i = 0; i < self->monitors->len; i++)
     {
-      GdkMonitor *monitor = g_ptr_array_index (self->monitors, i);
-      GdkRectangle intersect;
+      monitor = g_ptr_array_index (self->monitors, i);
 
       if (gdk_rectangle_intersect (&monitor->geometry, &rect, &intersect))
         {
@@ -1024,13 +1120,62 @@ _gdk_macos_surface_get_best_monitor (GdkMacosSurface *self)
 
           if (area > best_area)
             {
-              best = monitor;
               best_area = area;
+              best = monitor;
             }
         }
     }
 
-  return best;
+  if (g_set_object (&self->best_monitor, best))
+    {
+      GDK_NOTE (MISC,
+                g_message ("Surface \"%s\" moved to monitor \"%s\"",
+                           self->title ? self->title : "unknown",
+                           gdk_monitor_get_connector (best)));
+
+      _gdk_macos_surface_configure (self);
+
+      if (GDK_SURFACE_IS_MAPPED (GDK_SURFACE (self)))
+        {
+          _gdk_macos_surface_request_frame (self);
+          gdk_surface_request_layout (GDK_SURFACE (self));
+        }
+
+      for (const GList *iter = GDK_SURFACE (self)->children;
+           iter != NULL;
+           iter = iter->next)
+        {
+          GdkMacosSurface *child = iter->data;
+          GdkRectangle area;
+
+          g_set_object (&child->best_monitor, best);
+
+          area.x = self->root_x + GDK_SURFACE (child)->x + child->shadow_left;
+          area.y = self->root_y + GDK_SURFACE (child)->y + child->shadow_top;
+          area.width = GDK_SURFACE (child)->width - child->shadow_left - child->shadow_right;
+          area.height = GDK_SURFACE (child)->height - child->shadow_top - child->shadow_bottom;
+
+          _gdk_macos_monitor_clamp (GDK_MACOS_MONITOR (best), &area);
+
+          area.x -= child->shadow_left;
+          area.y -= child->shadow_top;
+
+          _gdk_macos_surface_move (child, area.x, area.y);
+          gdk_surface_invalidate_rect (GDK_SURFACE (child), NULL);
+        }
+    }
+
+  gdk_surface_invalidate_rect (GDK_SURFACE (self), NULL);
+
+  self->in_change_monitor = FALSE;
+}
+
+GdkMonitor *
+_gdk_macos_surface_get_best_monitor (GdkMacosSurface *self)
+{
+  g_return_val_if_fail (GDK_IS_MACOS_SURFACE (self), NULL);
+
+  return self->best_monitor;
 }
 
 NSView *
@@ -1077,3 +1222,70 @@ _gdk_macos_surface_get_root_coords (GdkMacosSurface *self,
   if (y)
     *y = out_y;
 }
+
+GdkMacosBuffer *
+_gdk_macos_surface_get_buffer (GdkMacosSurface *self)
+{
+  g_return_val_if_fail (GDK_IS_MACOS_SURFACE (self), NULL);
+
+  if (GDK_SURFACE_DESTROYED (self))
+    return NULL;
+
+  if (self->buffer == NULL)
+    {
+      /* Create replacement buffer. We always use 4-byte and 32-bit BGRA for
+       * our surface as that can work with both Cairo and GL. The GdkMacosTile
+       * handles opaque regions for the compositor, so using 3-byte/24-bit is
+       * not a necessary optimization.
+       */
+      double scale = gdk_surface_get_scale_factor (GDK_SURFACE (self));
+      guint width = GDK_SURFACE (self)->width * scale;
+      guint height = GDK_SURFACE (self)->height * scale;
+
+      self->buffer = _gdk_macos_buffer_new (width, height, scale, 4, 32);
+    }
+
+  return self->buffer;
+}
+
+static void
+_gdk_macos_surface_do_delayed_show (GdkMacosSurface *self)
+{
+  GdkSurface *surface = (GdkSurface *)self;
+
+  g_assert (GDK_IS_MACOS_SURFACE (self));
+
+  self->show_on_next_swap = FALSE;
+  [self->window showAndMakeKey:YES];
+
+  _gdk_macos_display_clear_sorting (GDK_MACOS_DISPLAY (surface->display));
+  gdk_surface_request_motion (surface);
+}
+
+void
+_gdk_macos_surface_swap_buffers (GdkMacosSurface      *self,
+                                 const cairo_region_t *damage)
+{
+  GdkMacosBuffer *swap;
+
+  g_return_if_fail (GDK_IS_MACOS_SURFACE (self));
+  g_return_if_fail (damage != NULL);
+
+  swap = self->buffer;
+  self->buffer = self->front;
+  self->front = swap;
+
+  /* This code looks like it swaps buffers, but since the IOSurfaceRef
+   * appears to be retained on the other side, we really just ask all
+   * of the GdkMacosTile CALayer's to update their contents.
+   */
+  [self->window swapBuffer:swap withDamage:damage];
+
+  /* We might have delayed actually showing the window until the buffer
+   * contents are ready to be displayed. Doing so ensures that we don't
+   * get a point where we might have invalid buffer contents before we
+   * have content to display to the user.
+   */
+  if G_UNLIKELY (self->show_on_next_swap)
+    _gdk_macos_surface_do_delayed_show (self);
+}
