@@ -945,38 +945,71 @@ _gdk_win32_enable_hidpi (GdkWin32Display *display)
     }
 }
 
-static void
-_gdk_win32_check_on_arm64 (GdkWin32Display *display)
+gboolean
+_gdk_win32_check_processor (GdkWin32ProcessorCheckType check_type)
 {
   static gsize checked = 0;
+  static gboolean is_arm64 = FALSE;
+  static gboolean is_wow64 = FALSE;
 
   if (g_once_init_enter (&checked))
     {
+      gboolean fallback_wow64_check = FALSE;
       HMODULE kernel32 = LoadLibraryW (L"kernel32.dll");
 
       if (kernel32 != NULL)
         {
-          display->cpu_funcs.isWow64Process2 =
+          typedef BOOL (WINAPI *funcIsWow64Process2) (HANDLE, USHORT *, USHORT *);
+
+          funcIsWow64Process2 isWow64Process2 =
             (funcIsWow64Process2) GetProcAddress (kernel32, "IsWow64Process2");
 
-          if (display->cpu_funcs.isWow64Process2 != NULL)
+          if (isWow64Process2 != NULL)
             {
               USHORT proc_cpu = 0;
               USHORT native_cpu = 0;
 
-              display->cpu_funcs.isWow64Process2 (GetCurrentProcess (),
-                                                  &proc_cpu,
-                                                  &native_cpu);
+              isWow64Process2 (GetCurrentProcess (), &proc_cpu, &native_cpu);
 
               if (native_cpu == IMAGE_FILE_MACHINE_ARM64)
-                display->running_on_arm64 = TRUE;
+                is_arm64 = TRUE;
+
+              if (proc_cpu != IMAGE_FILE_MACHINE_UNKNOWN)
+                is_wow64 = TRUE;
+            }
+          else
+            {
+              fallback_wow64_check = TRUE;
             }
 
           FreeLibrary (kernel32);
         }
+      else
+        {
+          fallback_wow64_check = TRUE;
+        }
+
+      if (fallback_wow64_check)
+        IsWow64Process (GetCurrentProcess (), &is_wow64);
 
       g_once_init_leave (&checked, 1);
     }
+
+  switch (check_type)
+    {
+      case GDK_WIN32_ARM64:
+        return is_arm64;
+        break;
+
+      case GDK_WIN32_WOW64:
+        return is_wow64;
+        break;
+
+      default:
+        g_warning ("unknown CPU check type");
+        return FALSE;
+        break;
+    }
 }
 
 static void
@@ -987,7 +1020,7 @@ gdk_win32_display_init (GdkWin32Display *display_win32)
   display_win32->monitors = G_LIST_MODEL (g_list_store_new (GDK_TYPE_MONITOR));
 
   _gdk_win32_enable_hidpi (display_win32);
-  _gdk_win32_check_on_arm64 (display_win32);
+  display_win32->running_on_arm64 = _gdk_win32_check_processor (GDK_WIN32_ARM64);
 
   /* if we have DPI awareness, set up fixed scale if set */
   if (display_win32->dpi_aware_type != PROCESS_DPI_UNAWARE &&
@@ -1142,16 +1175,18 @@ gdk_win32_display_get_setting (GdkDisplay  *display,
 #define EGL_PLATFORM_ANGLE_ANGLE          0x3202
 #endif
 
-static gboolean
-gdk_win32_display_init_gl_backend (GdkDisplay  *display,
-                                   GError     **error)
+static GdkGLContext *
+gdk_win32_display_init_gl (GdkDisplay  *display,
+                           GError     **error)
 {
-  gboolean result = FALSE;
   GdkWin32Display *display_win32 = GDK_WIN32_DISPLAY (display);
+  HDC init_gl_hdc = NULL;
 
   if (display_win32->dummy_context_wgl.hdc == NULL)
     display_win32->dummy_context_wgl.hdc = GetDC (display_win32->hwnd);
 
+  init_gl_hdc = display_win32->dummy_context_wgl.hdc;
+
   /*
    * No env vars set, do the regular GL initialization, first WGL and then EGL,
    * as WGL is the more tried-and-tested configuration.
@@ -1159,59 +1194,50 @@ gdk_win32_display_init_gl_backend (GdkDisplay  *display,
 
 #ifdef HAVE_EGL
   /*
-   * Disable defaulting to EGL for now, since shaders need to be fixed for
-   * usage against libANGLE EGL.  EGL is used more as a compatibility layer
+   * Disable defaulting to EGL as EGL is used more as a compatibility layer
    * on Windows rather than being a native citizen on Windows
    */
-  if (_gdk_debug_flags & GDK_DEBUG_GL_EGL)
-    result = gdk_display_init_egl (display,
-                                   EGL_PLATFORM_ANGLE_ANGLE,
-                                   display_win32->dummy_context_wgl.hdc,
-                                   FALSE,
-                                   error);
-#endif
-
-  if (!result)
+  if (GDK_DEBUG_CHECK (GL_EGL) || GDK_DEBUG_CHECK (GL_GLES))
     {
-      g_clear_error (error);
-      result = gdk_win32_display_init_wgl (display, error);
-    }
-
-#ifdef HAVE_EGL
-  if (!result)
-    {
-      g_clear_error (error);
-      result = gdk_display_init_egl (display,
-                                     EGL_PLATFORM_ANGLE_ANGLE,
-                                     display_win32->dummy_context_wgl.hdc,
-                                     TRUE,
-                                     error);
+      if (gdk_display_init_egl (display,
+                                EGL_PLATFORM_ANGLE_ANGLE,
+                                init_gl_hdc,
+                                FALSE,
+                                error))
+        {
+          return g_object_new (GDK_TYPE_WIN32_GL_CONTEXT_EGL,
+                               "display", display,
+                               NULL);
+        }
+      else
+        g_clear_error (error);
     }
 #endif
 
-  return result;
-}
+  if (gdk_win32_display_init_wgl (display, error))
+    {
+      return g_object_new (GDK_TYPE_WIN32_GL_CONTEXT_WGL,
+                           "display", display,
+                           NULL);
+    }
 
-static GdkGLContext *
-gdk_win32_display_init_gl (GdkDisplay  *display,
-                           GError     **error)
-{
-  GdkWin32Display *display_win32 = GDK_WIN32_DISPLAY (display);
-  GdkGLContext *gl_context = NULL;
-
-  if (!gdk_win32_display_init_gl_backend (display, error))
-    return NULL;
-
-  if (display_win32->wgl_pixel_format != 0)
-    gl_context = g_object_new (GDK_TYPE_WIN32_GL_CONTEXT_WGL, "display", display, NULL);
 #ifdef HAVE_EGL
-  else if (gdk_display_get_egl_display (display))
-    gl_context = g_object_new (GDK_TYPE_WIN32_GL_CONTEXT_EGL, "display", display, NULL);
+  g_clear_error (error);
+
+  if (gdk_display_init_egl (display,
+                            EGL_PLATFORM_ANGLE_ANGLE,
+                            init_gl_hdc,
+                            TRUE,
+                            error))
+    {
+      return g_object_new (GDK_TYPE_WIN32_GL_CONTEXT_EGL,
+                           "display", display,
+                           NULL);
+
+    }
 #endif
 
-  g_return_val_if_fail (gl_context != NULL, NULL);
-
-  return gl_context;
+  return NULL;
 }
 
 /**
