@@ -8,7 +8,7 @@ G_BEGIN_DECLS
 
 void gsk_ensure_resources (void);
 
-int pango_glyph_string_num_glyphs (PangoGlyphString *glyphs);
+int pango_glyph_string_num_glyphs (PangoGlyphString *glyphs) G_GNUC_PURE;
 
 typedef struct _GskVulkanRender GskVulkanRender;
 typedef struct _GskVulkanRenderPass GskVulkanRenderPass;
