@@ -252,4 +252,29 @@ typedef enum {
   ATSPI_COORD_TYPE_PARENT,
 } AtspiCoordType;
 
+typedef enum {
+  ATSPI_COMPONENT_LAYER_INVALID,
+  ATSPI_COMPONENT_LAYER_BACKGROUND,
+  ATSPI_COMPONENT_LAYER_CANVAS,
+  ATSPI_COMPONENT_LAYER_WIDGET,
+  ATSPI_COMPONENT_LAYER_MDI,
+  ATSPI_COMPONENT_LAYER_POPUP,
+  ATSPI_COMPONENT_LAYER_OVERLAY,
+  ATSPI_COMPONENT_LAYER_WINDOW
+} AtspiComponentLayer;
+
+typedef enum {
+  ATSPI_SCROLL_TOP_LEFT,
+  ATSPI_SCROLL_BOTTOM_RIGHT,
+  ATSPI_SCROLL_TOP_EDGE,
+  ATSPI_SCROLL_BOTTOM_EDGE,
+  ATSPI_SCROLL_LEFT_EDGE,
+  ATSPI_SCROLL_RIGHT_EDGE,
+  ATSPI_SCROLL_ANYWHERE
+} AtspiScrollType;
+
+typedef struct _GtkAtSpiRoot    GtkAtSpiRoot;
+typedef struct _GtkAtSpiCache   GtkAtSpiCache;
+typedef struct _GtkAtSpiContext GtkAtSpiContext;
+
 G_END_DECLS
