@@ -91,7 +91,7 @@ G_DEFINE_TYPE_WITH_PRIVATE (GtkInspectorCssNodeTree, gtk_inspector_css_node_tree
 
 typedef struct {
   GtkCssNode *node;
-  const gchar *prop_name;
+  const char *prop_name;
   GdkRectangle rect;
   GtkInspectorCssNodeTree *cnt;
 } NodePropEditor;
@@ -276,13 +276,13 @@ strv_sort (char **strv)
                      NULL);
 }
 
-static gchar *
+static char *
 format_state_flags (GtkStateFlags state)
 {
   if (state)
     {
       GString *str;
-      gint i;
+      int i;
       gboolean first = TRUE;
 
       str = g_string_new ("");
@@ -348,7 +348,7 @@ static void
 gtk_inspector_css_node_tree_init (GtkInspectorCssNodeTree *cnt)
 {
   GtkInspectorCssNodeTreePrivate *priv;
-  gint i;
+  int i;
 
   cnt->priv = gtk_inspector_css_node_tree_get_instance_private (cnt);
   gtk_widget_init_template (GTK_WIDGET (cnt));
@@ -375,7 +375,7 @@ gtk_inspector_css_node_tree_init (GtkInspectorCssNodeTree *cnt)
     {
       GtkCssStyleProperty *prop;
       GtkTreeIter iter;
-      const gchar *name;
+      const char *name;
 
       prop = _gtk_css_style_property_lookup_by_id (i);
       name = _gtk_style_property_get_name (GTK_STYLE_PROPERTY (prop));
@@ -433,16 +433,16 @@ gtk_inspector_css_node_tree_update_style (GtkInspectorCssNodeTree *cnt,
                                           GtkCssStyle             *new_style)
 {
   GtkInspectorCssNodeTreePrivate *priv = cnt->priv;
-  gint i;
+  int i;
 
   for (i = 0; i < _gtk_css_style_property_get_n_properties (); i++)
     {
       GtkCssStyleProperty *prop;
-      const gchar *name;
+      const char *name;
       GtkTreeIter *iter;
       GtkCssSection *section;
-      gchar *location;
-      gchar *value;
+      char *location;
+      char *value;
 
       prop = _gtk_css_style_property_lookup_by_id (i);
       name = _gtk_style_property_get_name (GTK_STYLE_PROPERTY (prop));
@@ -522,7 +522,7 @@ gtk_inspector_css_node_tree_set_display (GtkInspectorCssNodeTree *cnt,
                                          GdkDisplay *display)
 {
   GtkSettings *settings;
-  gchar *theme_name;
+  char *theme_name;
 
   settings = gtk_settings_get_for_display (display);
   g_object_get (settings, "gtk-theme-name", &theme_name, NULL);
