@@ -57,7 +57,7 @@ drag_drop (GtkDropTarget *dest,
 }
 
 static GtkWidget *
-create_row (const gchar *text)
+create_row (const char *text)
 {
   GtkWidget *row, *box, *label, *image;
   GtkDragSource *source;
@@ -101,12 +101,6 @@ on_selected_children_changed (GtkListBox *self)
   g_message ("Selection changed");
 }
 
-static void
-a11y_selection_changed (AtkObject *obj)
-{
-  g_message ("Accessible selection changed");
-}
-
 static void
 selection_mode_changed (GtkComboBox *combo, gpointer data)
 {
@@ -126,8 +120,8 @@ main (int argc, char *argv[])
 {
   GtkWidget *window, *list, *sw, *row;
   GtkWidget *hbox, *vbox, *combo, *button;
-  gint i;
-  gchar *text;
+  int i;
+  char *text;
   GtkCssProvider *provider;
 
   gtk_init ();
@@ -152,9 +146,8 @@ main (int argc, char *argv[])
 
   g_signal_connect (list, "row-activated", G_CALLBACK (on_row_activated), NULL);
   g_signal_connect (list, "selected-rows-changed", G_CALLBACK (on_selected_children_changed), NULL);
-  g_signal_connect (gtk_widget_get_accessible (list), "selection-changed", G_CALLBACK (a11y_selection_changed), NULL);
 
-  sw = gtk_scrolled_window_new (NULL, NULL);
+  sw = gtk_scrolled_window_new ();
   gtk_widget_set_hexpand (sw, TRUE);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
   gtk_box_append (GTK_BOX (hbox), sw);
